package com.gic.store.service.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.store.dao.mapper.TabStoreStrategyMapper;
import com.gic.store.dto.StoreStrategyDTO;
import com.gic.store.entity.TabStoreStrategy;
import com.gic.store.service.StoreStrategyService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author guojx
 * @date 2019/7/4 9:47 AM
 */
@Service("storeStrategyService")
public class StoreStrategyServiceImpl implements StoreStrategyService{

    @Autowired
    private TabStoreStrategyMapper tabStoreStrategyMapper;

    @Override
    public int saveStoreGroupStrategy(StoreStrategyDTO storeStrategyDTO) {
        TabStoreStrategy storeStrategy = EntityUtil.changeEntityNew(TabStoreStrategy.class, storeStrategyDTO);
        tabStoreStrategyMapper.insert(storeStrategy);
        return storeStrategy.getStoreRegionId();
    }

    @Override
    public boolean isRepeatGroupStrategyName(TabStoreStrategy record) {
        Integer count = tabStoreStrategyMapper.countRepeatStrategyName(record);
        if (count != null && count > 0) {
            return true;
        }
        return false;
    }

    @Override
    public TabStoreStrategy getStoreStrategyById(Integer strategyId) {
        return tabStoreStrategyMapper.selectByPrimaryKey(strategyId);
    }

    @Override
    public TabStoreStrategy getNextSort(int enterpriseId, double sort, int strategyType) {
        return tabStoreStrategyMapper.selectNextByEnterpriseIdAndSort(enterpriseId, sort, strategyType);
    }

    @Override
    public TabStoreStrategy getPrevSort(int enterpriseId, double sort, int strategyType) {
        return tabStoreStrategyMapper.selectPrevByStoreFieldIdAndSort(enterpriseId, sort, strategyType);
    }

    @Override
    public void setStoreStrategySort(int strategyId, int enterpriseId, int setValue, int strategyType) {
        if (setValue <= 1) {
            // 相当于置顶
            sortTopping(enterpriseId, strategyId, strategyType);
        } else {
            int start = setValue - 2;
            int size = 2;

            List<TabStoreStrategy> list = tabStoreStrategyMapper.listTwoElementExceptId(strategyId, start, size, enterpriseId, strategyType);
            if (CollectionUtils.isEmpty(list)) {
                // 置底
                sortBottom(enterpriseId, strategyId, strategyType);
            } else {
                Double sort;
                if (list.size() == 1) {
                    // 置底
                    sort = list.get(0).getSort() + 1d;
                } else {
                    sort = (list.get(0).getSort() + list.get(1).getSort()) / 2d;
                }
                updateSortById(strategyId, sort);
            }
        }
    }

    @Override
    public double getMinSort(int enterpriseId, int strategyType) {
        Double sort = tabStoreStrategyMapper.getMinSort(enterpriseId, strategyType);
        return sort == null ? 1d : sort;
    }

    @Override
    public void sortBottom(int enterpriseId, int strategyId, int strategyType) {
        Double sort = getMaxSort(enterpriseId, strategyType);
        updateSortById(strategyId, sort + 1d);
    }

    @Override
    public void sortTopping(int enterpriseId, int strategyId, int strategyType) {
        Double sort = getMinSort(enterpriseId, strategyType);
        updateSortById(strategyId, sort - 1d);
    }

    @Override
    public int deleteStoreGroupStrategy(int strategyId) {
        TabStoreStrategy storeStrategy = new TabStoreStrategy();
        storeStrategy.setStrategyId(strategyId);
        storeStrategy.setStatus(0);
        return tabStoreStrategyMapper.updateByPrimaryKeySelective(storeStrategy);
    }

    @Override
    public int modifyStoreGroupStrategy(StoreStrategyDTO storeStrategyDTO) {
        return tabStoreStrategyMapper.updateByPrimaryKeySelective(EntityUtil.changeEntityNew(TabStoreStrategy.class, storeStrategyDTO));
    }

    @Override
    public Page<TabStoreStrategy> listStoreStrategy(int enterpriseId, String search, int strategyType, Integer pageNum, Integer pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<TabStoreStrategy> list = tabStoreStrategyMapper.listStoreStrategy(enterpriseId, search, strategyType);
        return (Page<TabStoreStrategy>) list;
    }

    public double getMaxSort(int enterpriseId, int strategyType) {
        Double sort = tabStoreStrategyMapper.getMaxSort(enterpriseId, strategyType);
        return sort == null ? 1d : sort;
    }

    @Override
    public void updateSortById(int strategyId, double sort) {
        TabStoreStrategy storeStrategy = new TabStoreStrategy();
        storeStrategy.setStrategyId(strategyId);
        storeStrategy.setSort(sort);
        tabStoreStrategyMapper.updateByPrimaryKeySelective(storeStrategy);
    }

}
