package com.gic.store.service.outer;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.PageHelperUtils;
import com.gic.store.dto.StoreTmpDTO;
import com.gic.store.entity.TabStoreBrand;
import com.gic.store.entity.TabStoreGroup;
import com.gic.store.service.*;
import com.gic.store.utils.ErrorCode;
import com.task.allocation.exception.TaskAllocationException;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author zhiwj
 * @date 2019/7/3
 */
@Service("storeImportApiService")
@SuppressWarnings("unchecked")
public class StoreImportApiServiceImpl implements StoreImportApiService {

    private static final Logger logger = LogManager.getLogger(StoreBrandApiServiceImpl.class);

    @Autowired
    private StoreBrandService storeBrandService;

    @Autowired
    private StoreService storeService;

    @Autowired
    private StoreImportService storeImportService;

    @Autowired
    private StoreGroupService storeGroupService;

    @Autowired
    private StoreTaskService storeTaskService;

    @Override
    public ServiceResponse<Boolean> hasImportingStore(Integer enterpriseId) {
        return ServiceResponse.success(storeImportService.hasImportingStore(enterpriseId));
    }

    @Override
    public void delStoreTmp(Integer enterpriseId) {
        storeImportService.delStoreTmp(enterpriseId);
    }

    @Override
    public void save(StoreTmpDTO bean) {
        storeImportService.save(bean);
    }

    @Override
    public ServiceResponse<Page> listStoreTmp(Integer enterpriseId, boolean isSuccess, Integer currentPage, Integer pageSize) {
        com.github.pagehelper.Page storeTmpList = storeImportService.listStoreTmp(enterpriseId, isSuccess, currentPage, pageSize);
        Page<StoreTmpDTO> page = PageHelperUtils.changePageHelperToCurrentPage(storeTmpList, StoreTmpDTO.class);
        return ServiceResponse.success(page);
    }

    @Override
    public ServiceResponse<Boolean> validateStoreCode(Integer enterpriseId, String storeCode) {
        return ServiceResponse.success(storeService.countByStoreCode(enterpriseId, storeCode, null) > 0);
    }

    @Override
    public ServiceResponse<String> isExistStoreGroup(Integer enterpriseId, String storeGroupName) {
        TabStoreGroup group = storeGroupService.getStoreGroupByName(storeGroupName, enterpriseId);
        return ServiceResponse.success(group == null ? null : group.getStoreGroupName());
    }

    @Override
    public ServiceResponse<List<String>> listBrandByNotExist(Integer enterpriseId, String brands) {
        if (StringUtils.isBlank(brands)) {
            return ServiceResponse.success();
        }
        List<String> resultList = new ArrayList<>();
        List<TabStoreBrand> storeBrandList = storeBrandService.listAllStoreBrand(enterpriseId, null, null, null);
        if (CollectionUtils.isEmpty(storeBrandList)) {
            return ServiceResponse.success();
        }
        List<String> storeBrandNameList = storeBrandList.stream().map(TabStoreBrand::getStoreBrandName).collect(Collectors.toList());
        String[] brandArr = brands.split("、");
        // 这里如果门店品牌很多， 可以改成map 去做
        for (String brandName : brandArr) {
            if (!storeBrandNameList.contains(brandName)) {
                resultList.add(brandName);
            }
        }

        return ServiceResponse.success(resultList);
    }

    @Override
    public ServiceResponse<String> importDataToStore(Integer enterpriseId, String userId, String uuId) {
        try {
            return ServiceResponse.success(storeTaskService.importDataToStore(enterpriseId, userId, uuId));
        } catch (TaskAllocationException e) {
            logger.warn("队列错误");
        }
        return ServiceResponse.failure(ErrorCode.ERR_3.getCode(), "队列错误");
    }

//    @Autowired
//    TabStoreTmpMapper tabStoreTmpMapper;
//
//    @Override
//    public List<StoreTmpDTO> listStoreTmp(Integer enterpriseId, Boolean isSuccess, Boolean isWait) {
//        return EntityUtil.changeEntityListByOrika(StoreTmpDTO.class, tabStoreTmpMapper.listStoreTmp(enterpriseId, isSuccess, isWait));
//    }


}
