package com.gic.store.web.controller;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.store.constant.CreateTypeEnum;
import com.gic.store.dto.StoreBusinessTimeDTO;
import com.gic.store.dto.StoreDTO;
import com.gic.store.dto.StoreExtendDTO;
import com.gic.store.dto.StorePhotoDTO;
import com.gic.store.service.StoreApiService;
import com.gic.store.utils.ErrorCode;
import com.gic.store.web.ExcelUtils;
import com.gic.store.web.qo.PageQO;
import com.gic.store.web.qo.store.StoreQO;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * @author zhiwj
 * @date 2019/6/28
 */
@RestController
public class StoreController {

    private static final Logger logger = LogManager.getLogger(StoreController.class);

    @Autowired
    private StoreApiService storeApiService;

    @RequestMapping("/save-store")
    public RestResponse saveOrUpdate(StoreQO storeQO) {
        Integer enterpriseId = 1111;
        StoreDTO storeDTO = EntityUtil.changeEntityByOrika(StoreDTO.class, storeQO);
        storeDTO.setEnterpriseId(enterpriseId);
        String photos = storeQO.getPhotos();
        if (StringUtils.isNotBlank(photos)) {
            List<StorePhotoDTO> photoList = JSON.parseArray(photos, StorePhotoDTO.class);
            storeDTO.setPhotoList(photoList);
        }
        String businessTimes = storeQO.getBusinessTimes();
        if (StringUtils.isNotBlank(businessTimes)) {
            List<StoreBusinessTimeDTO> businessTimeList = JSON.parseArray(businessTimes, StoreBusinessTimeDTO.class);
            storeDTO.setBusinessTimeList(businessTimeList);
        }
        storeDTO.setCreateType(CreateTypeEnum.BACKGROUND_ADD.getCode());
        String fieldJson = storeQO.getFieldJson();
        List<StoreExtendDTO> extendList = JSON.parseArray(fieldJson, StoreExtendDTO.class);
        storeDTO.setStoreExtendList(extendList);
        ServiceResponse<Integer> serviceResponse = storeApiService.saveOrUpdate(storeDTO);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/store-detail")
    public RestResponse getStoreDetail(Integer storeId) {
        Integer enterpriseId = 1111;
        ServiceResponse<StoreDTO> serviceResponse = storeApiService.getStoreById(enterpriseId, storeId);
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

    @RequestMapping("/store-list")
    public RestResponse storeList(StoreDTO storeDTO, PageQO pageQO) {
        ServiceResponse<Page<StoreDTO>> serviceResponse = storeApiService.listStore(storeDTO, pageQO.getCurrentPage(), pageQO.getPageSize());
        if (serviceResponse.isSuccess()) {
            return RestResponse.success(serviceResponse.getResult());
        } else {
            return RestResponse.failure(serviceResponse.getCode(), serviceResponse.getMessage());
        }
    }

}